@@ -6,5 +6,7 @@ MAJOR = sys.version_info[0]
 
 if MAJOR == 3:
     cmp = lambda a, b: (a > b) - (a < b)  # pragma: no cover
+    basestring = str  # pragma: no cover
 else:  # hopefully MAJOR == 2
     cmp = cmp  # pragma: no cover
+    basestring = basestring  # pragma: no cover
